@@ -7,7 +7,7 @@ use crate::{
     ObjectLit,
 };
 use is_macro::Is;
-use swc_common::{ast_node, EqIgnoreSpan, Span};
+use swc_common::{ast_node, util::take::Take, EqIgnoreSpan, Span, DUMMY_SP};
 
 #[ast_node]
 #[derive(Eq, Hash, Is, EqIgnoreSpan)]
@@ -41,6 +41,12 @@ pub enum ModuleDecl {
     TsNamespaceExport(TsNamespaceExportDecl),
 }
 
+impl Take for ModuleDecl {
+    fn dummy() -> Self {
+        ModuleDecl::Import(ImportDecl::dummy())
+    }
+}
+
 #[ast_node("ExportDefaultExpression")]
 #[derive(Eq, Hash, EqIgnoreSpan)]
 #[cfg_attr(feature = "arbitrary", derive(arbitrary::Arbitrary))]
@@ -80,6 +86,18 @@ pub struct ImportDecl {
     pub asserts: Option<ObjectLit>,
 }
 
+impl Take for ImportDecl {
+    fn dummy() -> Self {
+        ImportDecl {
+            span: DUMMY_SP,
+            specifiers: Take::dummy(),
+            src: Take::dummy(),
+            type_only: Default::default(),
+            asserts: Take::dummy(),
+        }
+    }
+}
+
 /// `export * from 'mod'`
 #[ast_node("ExportAllDeclaration")]
 #[derive(Eq, Hash, EqIgnoreSpan)]
